==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-floating-pane-resize-move-event-args.js <==
import { FloatingPaneResizeMoveEventArgs as FloatingPaneResizeMoveEventArgs_internal } from "./FloatingPaneResizeMoveEventArgs";
var IgrFloatingPaneResizeMoveEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrFloatingPaneResizeMoveEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrFloatingPaneResizeMoveEventArgs.prototype.createImplementation = function () {
        return new FloatingPaneResizeMoveEventArgs_internal();
    };
    Object.defineProperty(IgrFloatingPaneResizeMoveEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrFloatingPaneResizeMoveEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrFloatingPaneResizeMoveEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrFloatingPaneResizeMoveEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = new IgrFloatingPaneResizeMoveEventArgs();
                e._implementation = this.i.a;
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrFloatingPaneResizeMoveEventArgs;
}());
export { IgrFloatingPaneResizeMoveEventArgs };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-floating-pane-resize-move-event-args.js <==
import { IgrFloatingPaneResizeMoveEventArgsDetail } from "./igr-floating-pane-resize-move-event-args-detail";
import { FloatingPaneResizeMoveEventArgs as FloatingPaneResizeMoveEventArgs_internal } from "./FloatingPaneResizeMoveEventArgs";
var IgrFloatingPaneResizeMoveEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrFloatingPaneResizeMoveEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrFloatingPaneResizeMoveEventArgs.prototype.createImplementation = function () {
        return new FloatingPaneResizeMoveEventArgs_internal();
    };
    Object.defineProperty(IgrFloatingPaneResizeMoveEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrFloatingPaneResizeMoveEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrFloatingPaneResizeMoveEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrFloatingPaneResizeMoveEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.b;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrFloatingPaneResizeMoveEventArgsDetail();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrFloatingPaneResizeMoveEventArgs;
}());
export { IgrFloatingPaneResizeMoveEventArgs };
